# The PEP 484 type hints stub file for the Qt3DInput module.
#
# Generated by SIP 6.15.1.dev0+g7378531ef.d20251218
#
# Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt6-3D.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import collections, re, typing, enum

try:
    from warnings import deprecated
except ImportError:
    pass

import PyQt6.sip

from PyQt6 import QtCore
from PyQt6 import QtGui
from PyQt6 import Qt3DCore

# Support for QDate, QDateTime and QTime.
import datetime

# Convenient type aliases.
PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[collections.abc.Callable[..., Any], QtCore.pyqtBoundSignal]


class QAbstractActionInput(Qt3DCore.QNode): ...


class QAbstractAxisInput(Qt3DCore.QNode):

    sourceDeviceChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setSourceDevice(self, sourceDevice: 'QAbstractPhysicalDevice|None') -> None: ...
    def sourceDevice(self) -> 'QAbstractPhysicalDevice|None': ...


class QAbstractPhysicalDevice(Qt3DCore.QNode):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    def axisSettings(self) -> list['QAxisSetting']: ...
    def removeAxisSetting(self, axisSetting: 'QAxisSetting|None') -> None: ...
    def addAxisSetting(self, axisSetting: 'QAxisSetting|None') -> None: ...
    def buttonIdentifier(self, name: str|None) -> int: ...
    def axisIdentifier(self, name: str|None) -> int: ...
    def buttonNames(self) -> list[str]: ...
    def axisNames(self) -> list[str]: ...
    def buttonCount(self) -> int: ...
    def axisCount(self) -> int: ...


class QAction(Qt3DCore.QNode):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    activeChanged: typing.ClassVar[QtCore.pyqtSignal]
    def inputs(self) -> list['QAbstractActionInput']: ...
    def removeInput(self, input: 'QAbstractActionInput|None') -> None: ...
    def addInput(self, input: 'QAbstractActionInput|None') -> None: ...
    def isActive(self) -> bool: ...


class QActionInput('QAbstractActionInput'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    buttonsChanged: typing.ClassVar[QtCore.pyqtSignal]
    sourceDeviceChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setButtons(self, buttons: collections.abc.Iterable[int]) -> None: ...
    def setSourceDevice(self, sourceDevice: 'QAbstractPhysicalDevice|None') -> None: ...
    def buttons(self) -> list[int]: ...
    def sourceDevice(self) -> 'QAbstractPhysicalDevice|None': ...


class QAnalogAxisInput('QAbstractAxisInput'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    axisChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setAxis(self, axis: int) -> None: ...
    def axis(self) -> int: ...


class QAxis(Qt3DCore.QNode):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def value(self) -> float: ...
    def inputs(self) -> list['QAbstractAxisInput']: ...
    def removeInput(self, input: 'QAbstractAxisInput|None') -> None: ...
    def addInput(self, input: 'QAbstractAxisInput|None') -> None: ...


class QAxisAccumulator(Qt3DCore.QComponent):

    class SourceAxisType(enum.Enum):
        Velocity = ... # type: QAxisAccumulator.SourceAxisType
        Acceleration = ... # type: QAxisAccumulator.SourceAxisType

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    scaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    velocityChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    sourceAxisTypeChanged: typing.ClassVar[QtCore.pyqtSignal]
    sourceAxisChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setScale(self, scale: float) -> None: ...
    def setSourceAxisType(self, sourceAxisType: 'QAxisAccumulator.SourceAxisType') -> None: ...
    def setSourceAxis(self, sourceAxis: 'QAxis|None') -> None: ...
    def scale(self) -> float: ...
    def velocity(self) -> float: ...
    def value(self) -> float: ...
    def sourceAxisType(self) -> 'QAxisAccumulator.SourceAxisType': ...
    def sourceAxis(self) -> 'QAxis|None': ...


class QAxisSetting(Qt3DCore.QNode):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    smoothChanged: typing.ClassVar[QtCore.pyqtSignal]
    axesChanged: typing.ClassVar[QtCore.pyqtSignal]
    deadZoneRadiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setSmoothEnabled(self, enabled: bool) -> None: ...
    def setAxes(self, axes: collections.abc.Iterable[int]) -> None: ...
    def setDeadZoneRadius(self, deadZoneRadius: float) -> None: ...
    def isSmoothEnabled(self) -> bool: ...
    def axes(self) -> list[int]: ...
    def deadZoneRadius(self) -> float: ...


class QButtonAxisInput('QAbstractAxisInput'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    decelerationChanged: typing.ClassVar[QtCore.pyqtSignal]
    accelerationChanged: typing.ClassVar[QtCore.pyqtSignal]
    buttonsChanged: typing.ClassVar[QtCore.pyqtSignal]
    scaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setDeceleration(self, deceleration: float) -> None: ...
    def setAcceleration(self, acceleration: float) -> None: ...
    def setButtons(self, buttons: collections.abc.Iterable[int]) -> None: ...
    def setScale(self, scale: float) -> None: ...
    def deceleration(self) -> float: ...
    def acceleration(self) -> float: ...
    def buttons(self) -> list[int]: ...
    def scale(self) -> float: ...


class QInputAspect(Qt3DCore.QAbstractAspect):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def availablePhysicalDevices(self) -> list[str]: ...
    def createPhysicalDevice(self, name: str|None) -> 'QAbstractPhysicalDevice|None': ...


class QInputChord('QAbstractActionInput'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    timeoutChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setTimeout(self, timeout: int) -> None: ...
    def chords(self) -> list['QAbstractActionInput']: ...
    def removeChord(self, input: 'QAbstractActionInput|None') -> None: ...
    def addChord(self, input: 'QAbstractActionInput|None') -> None: ...
    def timeout(self) -> int: ...


class QInputSequence('QAbstractActionInput'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    buttonIntervalChanged: typing.ClassVar[QtCore.pyqtSignal]
    timeoutChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setButtonInterval(self, buttonInterval: int) -> None: ...
    def setTimeout(self, timeout: int) -> None: ...
    def sequences(self) -> list['QAbstractActionInput']: ...
    def removeSequence(self, input: 'QAbstractActionInput|None') -> None: ...
    def addSequence(self, input: 'QAbstractActionInput|None') -> None: ...
    def buttonInterval(self) -> int: ...
    def timeout(self) -> int: ...


class QInputSettings(Qt3DCore.QComponent):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    eventSourceChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setEventSource(self, eventSource: QtCore.QObject|None) -> None: ...
    def eventSource(self) -> QtCore.QObject|None: ...


class QKeyboardDevice('QAbstractPhysicalDevice'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    activeInputChanged: typing.ClassVar[QtCore.pyqtSignal]
    def buttonIdentifier(self, name: str|None) -> int: ...
    def axisIdentifier(self, name: str|None) -> int: ...
    def buttonNames(self) -> list[str]: ...
    def axisNames(self) -> list[str]: ...
    def buttonCount(self) -> int: ...
    def axisCount(self) -> int: ...
    def activeInput(self) -> 'QKeyboardHandler|None': ...


class QKeyboardHandler(Qt3DCore.QComponent):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    released: typing.ClassVar[QtCore.pyqtSignal]
    pressed: typing.ClassVar[QtCore.pyqtSignal]
    volumeDownPressed: typing.ClassVar[QtCore.pyqtSignal]
    volumeUpPressed: typing.ClassVar[QtCore.pyqtSignal]
    menuPressed: typing.ClassVar[QtCore.pyqtSignal]
    flipPressed: typing.ClassVar[QtCore.pyqtSignal]
    hangupPressed: typing.ClassVar[QtCore.pyqtSignal]
    callPressed: typing.ClassVar[QtCore.pyqtSignal]
    context4Pressed: typing.ClassVar[QtCore.pyqtSignal]
    context3Pressed: typing.ClassVar[QtCore.pyqtSignal]
    context2Pressed: typing.ClassVar[QtCore.pyqtSignal]
    context1Pressed: typing.ClassVar[QtCore.pyqtSignal]
    noPressed: typing.ClassVar[QtCore.pyqtSignal]
    yesPressed: typing.ClassVar[QtCore.pyqtSignal]
    selectPressed: typing.ClassVar[QtCore.pyqtSignal]
    cancelPressed: typing.ClassVar[QtCore.pyqtSignal]
    backPressed: typing.ClassVar[QtCore.pyqtSignal]
    spacePressed: typing.ClassVar[QtCore.pyqtSignal]
    deletePressed: typing.ClassVar[QtCore.pyqtSignal]
    enterPressed: typing.ClassVar[QtCore.pyqtSignal]
    returnPressed: typing.ClassVar[QtCore.pyqtSignal]
    escapePressed: typing.ClassVar[QtCore.pyqtSignal]
    numberSignPressed: typing.ClassVar[QtCore.pyqtSignal]
    asteriskPressed: typing.ClassVar[QtCore.pyqtSignal]
    backtabPressed: typing.ClassVar[QtCore.pyqtSignal]
    tabPressed: typing.ClassVar[QtCore.pyqtSignal]
    downPressed: typing.ClassVar[QtCore.pyqtSignal]
    upPressed: typing.ClassVar[QtCore.pyqtSignal]
    rightPressed: typing.ClassVar[QtCore.pyqtSignal]
    leftPressed: typing.ClassVar[QtCore.pyqtSignal]
    digit9Pressed: typing.ClassVar[QtCore.pyqtSignal]
    digit8Pressed: typing.ClassVar[QtCore.pyqtSignal]
    digit7Pressed: typing.ClassVar[QtCore.pyqtSignal]
    digit6Pressed: typing.ClassVar[QtCore.pyqtSignal]
    digit5Pressed: typing.ClassVar[QtCore.pyqtSignal]
    digit4Pressed: typing.ClassVar[QtCore.pyqtSignal]
    digit3Pressed: typing.ClassVar[QtCore.pyqtSignal]
    digit2Pressed: typing.ClassVar[QtCore.pyqtSignal]
    digit1Pressed: typing.ClassVar[QtCore.pyqtSignal]
    digit0Pressed: typing.ClassVar[QtCore.pyqtSignal]
    focusChanged: typing.ClassVar[QtCore.pyqtSignal]
    sourceDeviceChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setFocus(self, focus: bool) -> None: ...
    def setSourceDevice(self, keyboardDevice: 'QKeyboardDevice|None') -> None: ...
    def focus(self) -> bool: ...
    def sourceDevice(self) -> 'QKeyboardDevice|None': ...


class QKeyEvent(QtCore.QObject):

    @typing.overload
    def __init__(self, type: QtCore.QEvent.Type, key: int, modifiers: QtCore.Qt.KeyboardModifier, text: str|None = ..., autorep: bool = ..., count: int = ...) -> None: ...
    @typing.overload
    def __init__(self, ke: QtGui.QKeyEvent) -> None: ...

    def matches(self, key_: QtGui.QKeySequence.StandardKey) -> bool: ...
    def type(self) -> QtCore.QEvent.Type: ...
    def setAccepted(self, accepted: bool) -> None: ...
    def isAccepted(self) -> bool: ...
    def nativeScanCode(self) -> int: ...
    def count(self) -> int: ...
    def isAutoRepeat(self) -> bool: ...
    def modifiers(self) -> int: ...
    def text(self) -> str: ...
    def key(self) -> int: ...


class QLogicalDevice(Qt3DCore.QComponent):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    def axes(self) -> list['QAxis']: ...
    def removeAxis(self, axis: 'QAxis|None') -> None: ...
    def addAxis(self, axis: 'QAxis|None') -> None: ...
    def actions(self) -> list['QAction']: ...
    def removeAction(self, action: 'QAction|None') -> None: ...
    def addAction(self, action: 'QAction|None') -> None: ...


class QMouseDevice('QAbstractPhysicalDevice'):

    class Axis(enum.Enum):
        X = ... # type: QMouseDevice.Axis
        Y = ... # type: QMouseDevice.Axis
        WheelX = ... # type: QMouseDevice.Axis
        WheelY = ... # type: QMouseDevice.Axis

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    updateAxesContinuouslyChanged: typing.ClassVar[QtCore.pyqtSignal]
    sensitivityChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setUpdateAxesContinuously(self, updateAxesContinuously: bool) -> None: ...
    def setSensitivity(self, value: float) -> None: ...
    def sensitivity(self) -> float: ...
    def updateAxesContinuously(self) -> bool: ...
    def buttonIdentifier(self, name: str|None) -> int: ...
    def axisIdentifier(self, name: str|None) -> int: ...
    def buttonNames(self) -> list[str]: ...
    def axisNames(self) -> list[str]: ...
    def buttonCount(self) -> int: ...
    def axisCount(self) -> int: ...


class QMouseEvent(QtCore.QObject):

    class Modifiers(enum.Enum):
        NoModifier = ... # type: QMouseEvent.Modifiers
        ShiftModifier = ... # type: QMouseEvent.Modifiers
        ControlModifier = ... # type: QMouseEvent.Modifiers
        AltModifier = ... # type: QMouseEvent.Modifiers
        MetaModifier = ... # type: QMouseEvent.Modifiers
        KeypadModifier = ... # type: QMouseEvent.Modifiers

    class Buttons(enum.Enum):
        LeftButton = ... # type: QMouseEvent.Buttons
        RightButton = ... # type: QMouseEvent.Buttons
        MiddleButton = ... # type: QMouseEvent.Buttons
        BackButton = ... # type: QMouseEvent.Buttons
        NoButton = ... # type: QMouseEvent.Buttons

    def __init__(self, e: QtGui.QMouseEvent) -> None: ...

    def type(self) -> QtCore.QEvent.Type: ...
    def setAccepted(self, accepted: bool) -> None: ...
    def isAccepted(self) -> bool: ...
    def modifiers(self) -> 'QMouseEvent.Modifiers': ...
    def buttons(self) -> int: ...
    def button(self) -> 'QMouseEvent.Buttons': ...
    def wasHeld(self) -> bool: ...
    def y(self) -> int: ...
    def x(self) -> int: ...


class QWheelEvent(QtCore.QObject):

    class Modifiers(enum.Enum):
        NoModifier = ... # type: QWheelEvent.Modifiers
        ShiftModifier = ... # type: QWheelEvent.Modifiers
        ControlModifier = ... # type: QWheelEvent.Modifiers
        AltModifier = ... # type: QWheelEvent.Modifiers
        MetaModifier = ... # type: QWheelEvent.Modifiers
        KeypadModifier = ... # type: QWheelEvent.Modifiers

    class Buttons(enum.Enum):
        LeftButton = ... # type: QWheelEvent.Buttons
        RightButton = ... # type: QWheelEvent.Buttons
        MiddleButton = ... # type: QWheelEvent.Buttons
        BackButton = ... # type: QWheelEvent.Buttons
        NoButton = ... # type: QWheelEvent.Buttons

    def __init__(self, e: QtGui.QWheelEvent) -> None: ...

    def type(self) -> QtCore.QEvent.Type: ...
    def setAccepted(self, accepted: bool) -> None: ...
    def isAccepted(self) -> bool: ...
    def modifiers(self) -> 'QWheelEvent.Modifiers': ...
    def buttons(self) -> int: ...
    def angleDelta(self) -> QtCore.QPoint: ...
    def y(self) -> int: ...
    def x(self) -> int: ...


class QMouseHandler(Qt3DCore.QComponent):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    wheel: typing.ClassVar[QtCore.pyqtSignal]
    positionChanged: typing.ClassVar[QtCore.pyqtSignal]
    pressAndHold: typing.ClassVar[QtCore.pyqtSignal]
    released: typing.ClassVar[QtCore.pyqtSignal]
    pressed: typing.ClassVar[QtCore.pyqtSignal]
    exited: typing.ClassVar[QtCore.pyqtSignal]
    entered: typing.ClassVar[QtCore.pyqtSignal]
    doubleClicked: typing.ClassVar[QtCore.pyqtSignal]
    clicked: typing.ClassVar[QtCore.pyqtSignal]
    containsMouseChanged: typing.ClassVar[QtCore.pyqtSignal]
    sourceDeviceChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setSourceDevice(self, mouseDevice: 'QMouseDevice|None') -> None: ...
    def containsMouse(self) -> bool: ...
    def sourceDevice(self) -> 'QMouseDevice|None': ...



# The PEP 484 type hints stub file for the Qt3DCore module.
#
# Generated by SIP 6.15.1.dev0+g7378531ef.d20251218
#
# Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt6-3D.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import collections, re, typing, enum

try:
    from warnings import deprecated
except ImportError:
    pass

import PyQt6.sip

from PyQt6 import QtCore
from PyQt6 import QtGui

# Support for QDate, QDateTime and QTime.
import datetime

# Convenient type aliases.
PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[collections.abc.Callable[..., Any], QtCore.pyqtBoundSignal]


class QAbstractAspect(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def unregisterBackendType(self, a0: QtCore.QMetaObject) -> None: ...
    def registerBackendType(self, a0: QtCore.QMetaObject, functor: 'QBackendNodeMapper') -> None: ...
    def rootEntityId(self) -> 'QNodeId': ...


class QAbstractFunctor(PyQt6.sip.simplewrapper):

    def __init__(self) -> None: ...

    def id(self) -> PyQt6.sip.voidptr: ...


class QNode(QtCore.QObject):

    def __init__(self, parent: 'QNode|None' = ...) -> None: ...

    nodeDestroyed: typing.ClassVar[QtCore.pyqtSignal]
    enabledChanged: typing.ClassVar[QtCore.pyqtSignal]
    parentChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setEnabled(self, isEnabled: bool) -> None: ...
    def setParent(self, parent: 'QNode|None') -> None: ...
    def isEnabled(self) -> bool: ...
    def childNodes(self) -> list['QNode']: ...
    def blockNotifications(self, block: bool) -> bool: ...
    def notificationsBlocked(self) -> bool: ...
    def parentNode(self) -> 'QNode|None': ...
    def id(self) -> 'QNodeId': ...


class QAbstractSkeleton('QNode'):

    jointCountChanged: typing.ClassVar[QtCore.pyqtSignal]
    def jointCount(self) -> int: ...


class QComponent('QNode'):

    def __init__(self, parent: 'QNode|None' = ...) -> None: ...

    removedFromEntity: typing.ClassVar[QtCore.pyqtSignal]
    addedToEntity: typing.ClassVar[QtCore.pyqtSignal]
    shareableChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setShareable(self, isShareable: bool) -> None: ...
    def entities(self) -> list['QEntity']: ...
    def isShareable(self) -> bool: ...


class QArmature('QComponent'):

    def __init__(self, parent: 'QNode|None' = ...) -> None: ...

    skeletonChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setSkeleton(self, skeleton: 'QAbstractSkeleton|None') -> None: ...
    def skeleton(self) -> 'QAbstractSkeleton|None': ...


class QAspectEngine(QtCore.QObject):

    class RunMode(enum.Enum):
        Manual = ... # type: QAspectEngine.RunMode
        Automatic = ... # type: QAspectEngine.RunMode

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def processFrame(self) -> None: ...
    def runMode(self) -> 'QAspectEngine.RunMode': ...
    def setRunMode(self, mode: 'QAspectEngine.RunMode') -> None: ...
    def executeCommand(self, command: str|None) -> typing.Any: ...
    def aspects(self) -> list['QAbstractAspect']: ...
    def aspect(self, name: str|None) -> 'QAbstractAspect|None': ...
    @typing.overload
    def unregisterAspect(self, aspect: 'QAbstractAspect|None') -> None: ...
    @typing.overload
    def unregisterAspect(self, name: str|None) -> None: ...
    @typing.overload
    def registerAspect(self, aspect: 'QAbstractAspect|None') -> None: ...
    @typing.overload
    def registerAspect(self, name: str|None) -> None: ...
    def rootEntity(self) -> 'QEntity': ...
    def setRootEntity(self, root: 'QEntity') -> None: ...


class QAttribute('QNode'):

    class VertexBaseType(enum.Enum):
        Byte = ... # type: QAttribute.VertexBaseType
        UnsignedByte = ... # type: QAttribute.VertexBaseType
        Short = ... # type: QAttribute.VertexBaseType
        UnsignedShort = ... # type: QAttribute.VertexBaseType
        Int = ... # type: QAttribute.VertexBaseType
        UnsignedInt = ... # type: QAttribute.VertexBaseType
        HalfFloat = ... # type: QAttribute.VertexBaseType
        Float = ... # type: QAttribute.VertexBaseType
        Double = ... # type: QAttribute.VertexBaseType

    class AttributeType(enum.Enum):
        VertexAttribute = ... # type: QAttribute.AttributeType
        IndexAttribute = ... # type: QAttribute.AttributeType
        DrawIndirectAttribute = ... # type: QAttribute.AttributeType

    @typing.overload
    def __init__(self, parent: 'QNode|None' = ...) -> None: ...
    @typing.overload
    def __init__(self, buf: 'QBuffer|None', vertexBaseType: 'QAttribute.VertexBaseType', vertexSize: int, count: int, offset: int = ..., stride: int = ..., parent: 'QNode|None' = ...) -> None: ...
    @typing.overload
    def __init__(self, buf: 'QBuffer|None', name: str|None, vertexBaseType: 'QAttribute.VertexBaseType', vertexSize: int, count: int, offset: int = ..., stride: int = ..., parent: 'QNode|None' = ...) -> None: ...

    attributeTypeChanged: typing.ClassVar[QtCore.pyqtSignal]
    divisorChanged: typing.ClassVar[QtCore.pyqtSignal]
    byteOffsetChanged: typing.ClassVar[QtCore.pyqtSignal]
    byteStrideChanged: typing.ClassVar[QtCore.pyqtSignal]
    countChanged: typing.ClassVar[QtCore.pyqtSignal]
    dataSizeChanged: typing.ClassVar[QtCore.pyqtSignal]
    dataTypeChanged: typing.ClassVar[QtCore.pyqtSignal]
    vertexSizeChanged: typing.ClassVar[QtCore.pyqtSignal]
    vertexBaseTypeChanged: typing.ClassVar[QtCore.pyqtSignal]
    nameChanged: typing.ClassVar[QtCore.pyqtSignal]
    bufferChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setAttributeType(self, attributeType: 'QAttribute.AttributeType') -> None: ...
    def setDivisor(self, divisor: int) -> None: ...
    def setByteOffset(self, byteOffset: int) -> None: ...
    def setByteStride(self, byteStride: int) -> None: ...
    def setCount(self, count: int) -> None: ...
    def setVertexSize(self, size: int) -> None: ...
    def setVertexBaseType(self, type: 'QAttribute.VertexBaseType') -> None: ...
    def setName(self, name: str|None) -> None: ...
    def setBuffer(self, buffer: 'QBuffer|None') -> None: ...
    @staticmethod
    def defaultTextureCoordinate2AttributeName() -> str: ...
    @staticmethod
    def defaultTextureCoordinate1AttributeName() -> str: ...
    @staticmethod
    def defaultJointWeightsAttributeName() -> str: ...
    @staticmethod
    def defaultJointIndicesAttributeName() -> str: ...
    @staticmethod
    def defaultTangentAttributeName() -> str: ...
    @staticmethod
    def defaultTextureCoordinateAttributeName() -> str: ...
    @staticmethod
    def defaultColorAttributeName() -> str: ...
    @staticmethod
    def defaultNormalAttributeName() -> str: ...
    @staticmethod
    def defaultPositionAttributeName() -> str: ...
    def attributeType(self) -> 'QAttribute.AttributeType': ...
    def divisor(self) -> int: ...
    def byteOffset(self) -> int: ...
    def byteStride(self) -> int: ...
    def count(self) -> int: ...
    def vertexSize(self) -> int: ...
    def vertexBaseType(self) -> 'QAttribute.VertexBaseType': ...
    def name(self) -> str: ...
    def buffer(self) -> 'QBuffer|None': ...


class QBackendNodeMapper(PyQt6.sip.simplewrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QBackendNodeMapper') -> None: ...

    def destroy(self, id: 'QNodeId') -> None: ...
    def get(self, id: 'QNodeId') -> 'QBackendNode|None': ...
    def create(self, id: 'QNodeId') -> 'QBackendNode|None': ...


class QBackendNode(PyQt6.sip.simplewrapper):

    class Mode(enum.Enum):
        ReadOnly = ... # type: QBackendNode.Mode
        ReadWrite = ... # type: QBackendNode.Mode

    def __init__(self, mode: 'QBackendNode.Mode' = ...) -> None: ...

    def syncFromFrontEnd(self, frontEnd: 'QNode|None', firstTime: bool) -> None: ...
    def mode(self) -> 'QBackendNode.Mode': ...
    def isEnabled(self) -> bool: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def peerId(self) -> 'QNodeId': ...


class QBoundingVolume('QComponent'):

    def __init__(self, parent: 'QNode|None' = ...) -> None: ...

    maxPointChanged: typing.ClassVar[QtCore.pyqtSignal]
    minPointChanged: typing.ClassVar[QtCore.pyqtSignal]
    implicitPointsValidChanged: typing.ClassVar[QtCore.pyqtSignal]
    implicitMaxPointChanged: typing.ClassVar[QtCore.pyqtSignal]
    implicitMinPointChanged: typing.ClassVar[QtCore.pyqtSignal]
    viewChanged: typing.ClassVar[QtCore.pyqtSignal]
    def updateImplicitBounds(self) -> bool: ...
    def setMaxPoint(self, maxPoint: QtGui.QVector3D) -> None: ...
    def setMinPoint(self, minPoint: QtGui.QVector3D) -> None: ...
    def setView(self, view: 'QGeometryView|None') -> None: ...
    def maxPoint(self) -> QtGui.QVector3D: ...
    def minPoint(self) -> QtGui.QVector3D: ...
    def areImplicitPointsValid(self) -> bool: ...
    def implicitMaxPoint(self) -> QtGui.QVector3D: ...
    def implicitMinPoint(self) -> QtGui.QVector3D: ...
    def view(self) -> 'QGeometryView|None': ...


class QBuffer('QNode'):

    class AccessType(enum.Enum):
        Write = ... # type: QBuffer.AccessType
        Read = ... # type: QBuffer.AccessType
        ReadWrite = ... # type: QBuffer.AccessType

    class UsageType(enum.Enum):
        StreamDraw = ... # type: QBuffer.UsageType
        StreamRead = ... # type: QBuffer.UsageType
        StreamCopy = ... # type: QBuffer.UsageType
        StaticDraw = ... # type: QBuffer.UsageType
        StaticRead = ... # type: QBuffer.UsageType
        StaticCopy = ... # type: QBuffer.UsageType
        DynamicDraw = ... # type: QBuffer.UsageType
        DynamicRead = ... # type: QBuffer.UsageType
        DynamicCopy = ... # type: QBuffer.UsageType

    def __init__(self, parent: 'QNode|None' = ...) -> None: ...

    dataAvailable: typing.ClassVar[QtCore.pyqtSignal]
    accessTypeChanged: typing.ClassVar[QtCore.pyqtSignal]
    usageChanged: typing.ClassVar[QtCore.pyqtSignal]
    dataChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setAccessType(self, access: 'QBuffer.AccessType') -> None: ...
    def setUsage(self, usage: 'QBuffer.UsageType') -> None: ...
    def updateData(self, offset: int, bytes: QtCore.QByteArray|bytes|bytearray|memoryview) -> None: ...
    def data(self) -> QtCore.QByteArray: ...
    def setData(self, bytes: QtCore.QByteArray|bytes|bytearray|memoryview) -> None: ...
    def accessType(self) -> 'QBuffer.AccessType': ...
    def usage(self) -> 'QBuffer.UsageType': ...


class QCoreSettings('QComponent'):

    def __init__(self, parent: 'QNode|None' = ...) -> None: ...

    boundingVolumesEnabledChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setBoundingVolumesEnabled(self, boundingVolumesEnabled: bool) -> None: ...
    def boundingVolumesEnabled(self) -> bool: ...


class QEntity('QNode'):

    def __init__(self, parent: 'QNode|None' = ...) -> None: ...

    def parentEntity(self) -> 'QEntity|None': ...
    def removeComponent(self, comp: 'QComponent|None') -> None: ...
    def addComponent(self, comp: 'QComponent|None') -> None: ...
    def components(self) -> list['QComponent']: ...


class QGeometry('QNode'):

    def __init__(self, parent: 'QNode|None' = ...) -> None: ...

    maxExtentChanged: typing.ClassVar[QtCore.pyqtSignal]
    minExtentChanged: typing.ClassVar[QtCore.pyqtSignal]
    boundingVolumePositionAttributeChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setBoundingVolumePositionAttribute(self, boundingVolumePositionAttribute: 'QAttribute|None') -> None: ...
    def maxExtent(self) -> QtGui.QVector3D: ...
    def minExtent(self) -> QtGui.QVector3D: ...
    def boundingVolumePositionAttribute(self) -> 'QAttribute|None': ...
    def removeAttribute(self, attribute: 'QAttribute|None') -> None: ...
    def addAttribute(self, attribute: 'QAttribute|None') -> None: ...
    def attributes(self) -> list['QAttribute']: ...


class QGeometryView('QNode'):

    class PrimitiveType(enum.Enum):
        Points = ... # type: QGeometryView.PrimitiveType
        Lines = ... # type: QGeometryView.PrimitiveType
        LineLoop = ... # type: QGeometryView.PrimitiveType
        LineStrip = ... # type: QGeometryView.PrimitiveType
        Triangles = ... # type: QGeometryView.PrimitiveType
        TriangleStrip = ... # type: QGeometryView.PrimitiveType
        TriangleFan = ... # type: QGeometryView.PrimitiveType
        LinesAdjacency = ... # type: QGeometryView.PrimitiveType
        TrianglesAdjacency = ... # type: QGeometryView.PrimitiveType
        LineStripAdjacency = ... # type: QGeometryView.PrimitiveType
        TriangleStripAdjacency = ... # type: QGeometryView.PrimitiveType
        Patches = ... # type: QGeometryView.PrimitiveType

    def __init__(self, parent: 'QNode|None' = ...) -> None: ...

    primitiveTypeChanged: typing.ClassVar[QtCore.pyqtSignal]
    geometryChanged: typing.ClassVar[QtCore.pyqtSignal]
    primitiveRestartEnabledChanged: typing.ClassVar[QtCore.pyqtSignal]
    verticesPerPatchChanged: typing.ClassVar[QtCore.pyqtSignal]
    restartIndexValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    indexBufferByteOffsetChanged: typing.ClassVar[QtCore.pyqtSignal]
    firstVertexChanged: typing.ClassVar[QtCore.pyqtSignal]
    firstInstanceChanged: typing.ClassVar[QtCore.pyqtSignal]
    indexOffsetChanged: typing.ClassVar[QtCore.pyqtSignal]
    vertexCountChanged: typing.ClassVar[QtCore.pyqtSignal]
    instanceCountChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setPrimitiveType(self, primitiveType: 'QGeometryView.PrimitiveType') -> None: ...
    def setGeometry(self, geometry: 'QGeometry|None') -> None: ...
    def setPrimitiveRestartEnabled(self, enabled: bool) -> None: ...
    def setVerticesPerPatch(self, verticesPerPatch: int) -> None: ...
    def setRestartIndexValue(self, index: int) -> None: ...
    def setIndexBufferByteOffset(self, offset: int) -> None: ...
    def setFirstVertex(self, firstVertex: int) -> None: ...
    def setFirstInstance(self, firstInstance: int) -> None: ...
    def setIndexOffset(self, indexOffset: int) -> None: ...
    def setVertexCount(self, vertexCount: int) -> None: ...
    def setInstanceCount(self, instanceCount: int) -> None: ...
    def primitiveType(self) -> 'QGeometryView.PrimitiveType': ...
    def geometry(self) -> 'QGeometry|None': ...
    def primitiveRestartEnabled(self) -> bool: ...
    def verticesPerPatch(self) -> int: ...
    def restartIndexValue(self) -> int: ...
    def indexBufferByteOffset(self) -> int: ...
    def firstVertex(self) -> int: ...
    def firstInstance(self) -> int: ...
    def indexOffset(self) -> int: ...
    def vertexCount(self) -> int: ...
    def instanceCount(self) -> int: ...


class QJoint('QNode'):

    def __init__(self, parent: 'QNode|None' = ...) -> None: ...

    nameChanged: typing.ClassVar[QtCore.pyqtSignal]
    rotationZChanged: typing.ClassVar[QtCore.pyqtSignal]
    rotationYChanged: typing.ClassVar[QtCore.pyqtSignal]
    rotationXChanged: typing.ClassVar[QtCore.pyqtSignal]
    inverseBindMatrixChanged: typing.ClassVar[QtCore.pyqtSignal]
    translationChanged: typing.ClassVar[QtCore.pyqtSignal]
    rotationChanged: typing.ClassVar[QtCore.pyqtSignal]
    scaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setToIdentity(self) -> None: ...
    def setName(self, name: str|None) -> None: ...
    def setRotationZ(self, rotationZ: float) -> None: ...
    def setRotationY(self, rotationY: float) -> None: ...
    def setRotationX(self, rotationX: float) -> None: ...
    def setInverseBindMatrix(self, inverseBindMatrix: QtGui.QMatrix4x4) -> None: ...
    def setTranslation(self, translation: QtGui.QVector3D) -> None: ...
    def setRotation(self, rotation: QtGui.QQuaternion) -> None: ...
    def setScale(self, scale: QtGui.QVector3D) -> None: ...
    def childJoints(self) -> list['QJoint']: ...
    def removeChildJoint(self, joint: 'QJoint|None') -> None: ...
    def addChildJoint(self, joint: 'QJoint|None') -> None: ...
    def name(self) -> str: ...
    def rotationZ(self) -> float: ...
    def rotationY(self) -> float: ...
    def rotationX(self) -> float: ...
    def inverseBindMatrix(self) -> QtGui.QMatrix4x4: ...
    def translation(self) -> QtGui.QVector3D: ...
    def rotation(self) -> QtGui.QQuaternion: ...
    def scale(self) -> QtGui.QVector3D: ...


class QNodeIdTypePair(PyQt6.sip.simplewrapper):

    id = ... # type: 'QNodeId'
    type = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, _id: 'QNodeId', _type: QtCore.QMetaObject|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QNodeIdTypePair') -> None: ...


class QNodeId(PyQt6.sip.simplewrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QNodeId') -> None: ...

    def __ge__(self, other: 'QNodeId') -> bool: ...
    def __le__(self, other: 'QNodeId') -> bool: ...
    def __hash__(self) -> int: ...
    def __int__(self) -> bool: ...
    def id(self) -> int: ...
    def __gt__(self, other: 'QNodeId') -> bool: ...
    def __lt__(self, other: 'QNodeId') -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def isNull(self) -> bool: ...
    @staticmethod
    def createId() -> 'QNodeId': ...


class QSkeleton('QAbstractSkeleton'):

    def __init__(self, parent: 'QNode|None' = ...) -> None: ...

    rootJointChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setRootJoint(self, rootJoint: 'QJoint|None') -> None: ...
    def rootJoint(self) -> 'QJoint|None': ...


class QSkeletonLoader('QAbstractSkeleton'):

    class Status(enum.Enum):
        NotReady = ... # type: QSkeletonLoader.Status
        Ready = ... # type: QSkeletonLoader.Status
        Error = ... # type: QSkeletonLoader.Status

    @typing.overload
    def __init__(self, parent: 'QNode|None' = ...) -> None: ...
    @typing.overload
    def __init__(self, source: QtCore.QUrl, parent: 'QNode|None' = ...) -> None: ...

    rootJointChanged: typing.ClassVar[QtCore.pyqtSignal]
    createJointsEnabledChanged: typing.ClassVar[QtCore.pyqtSignal]
    statusChanged: typing.ClassVar[QtCore.pyqtSignal]
    sourceChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setCreateJointsEnabled(self, enabled: bool) -> None: ...
    def setSource(self, source: QtCore.QUrl) -> None: ...
    def rootJoint(self) -> 'QJoint|None': ...
    def isCreateJointsEnabled(self) -> bool: ...
    def status(self) -> 'QSkeletonLoader.Status': ...
    def source(self) -> QtCore.QUrl: ...


class QTransform('QComponent'):

    def __init__(self, parent: 'QNode|None' = ...) -> None: ...

    worldMatrixChanged: typing.ClassVar[QtCore.pyqtSignal]
    rotationZChanged: typing.ClassVar[QtCore.pyqtSignal]
    rotationYChanged: typing.ClassVar[QtCore.pyqtSignal]
    rotationXChanged: typing.ClassVar[QtCore.pyqtSignal]
    matrixChanged: typing.ClassVar[QtCore.pyqtSignal]
    translationChanged: typing.ClassVar[QtCore.pyqtSignal]
    rotationChanged: typing.ClassVar[QtCore.pyqtSignal]
    scale3DChanged: typing.ClassVar[QtCore.pyqtSignal]
    scaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setRotationZ(self, rotationZ: float) -> None: ...
    def setRotationY(self, rotationY: float) -> None: ...
    def setRotationX(self, rotationX: float) -> None: ...
    def setMatrix(self, matrix: QtGui.QMatrix4x4) -> None: ...
    def setTranslation(self, translation: QtGui.QVector3D) -> None: ...
    def setRotation(self, rotation: QtGui.QQuaternion) -> None: ...
    def setScale3D(self, scale: QtGui.QVector3D) -> None: ...
    def setScale(self, scale: float) -> None: ...
    def rotationZ(self) -> float: ...
    def rotationY(self) -> float: ...
    def rotationX(self) -> float: ...
    def worldMatrix(self) -> QtGui.QMatrix4x4: ...
    def matrix(self) -> QtGui.QMatrix4x4: ...
    @staticmethod
    def rotateFromAxes(xAxis: QtGui.QVector3D, yAxis: QtGui.QVector3D, zAxis: QtGui.QVector3D) -> QtGui.QMatrix4x4: ...
    @staticmethod
    def rotateAround(point: QtGui.QVector3D, angle: float, axis: QtGui.QVector3D) -> QtGui.QMatrix4x4: ...
    @typing.overload
    @staticmethod
    def fromEulerAngles(eulerAngles: QtGui.QVector3D) -> QtGui.QQuaternion: ...
    @typing.overload
    @staticmethod
    def fromEulerAngles(pitch: float, yaw: float, roll: float) -> QtGui.QQuaternion: ...
    @typing.overload
    @staticmethod
    def fromAxesAndAngles(axis1: QtGui.QVector3D, angle1: float, axis2: QtGui.QVector3D, angle2: float) -> QtGui.QQuaternion: ...
    @typing.overload
    @staticmethod
    def fromAxesAndAngles(axis1: QtGui.QVector3D, angle1: float, axis2: QtGui.QVector3D, angle2: float, axis3: QtGui.QVector3D, angle3: float) -> QtGui.QQuaternion: ...
    @typing.overload
    @staticmethod
    def fromAxisAndAngle(axis: QtGui.QVector3D, angle: float) -> QtGui.QQuaternion: ...
    @typing.overload
    @staticmethod
    def fromAxisAndAngle(x: float, y: float, z: float, angle: float) -> QtGui.QQuaternion: ...
    @staticmethod
    def fromAxes(xAxis: QtGui.QVector3D, yAxis: QtGui.QVector3D, zAxis: QtGui.QVector3D) -> QtGui.QQuaternion: ...
    def translation(self) -> QtGui.QVector3D: ...
    def rotation(self) -> QtGui.QQuaternion: ...
    def scale3D(self) -> QtGui.QVector3D: ...
    def scale(self) -> float: ...


def qIdForNode(node: 'QNode|None') -> 'QNodeId': ...


PYQT_3D_VERSION = ... # type: int
PYQT_3D_VERSION_STR = ... # type: str



# The PEP 484 type hints stub file for the Qt3DExtras module.
#
# Generated by SIP 6.15.1.dev0+g7378531ef.d20251218
#
# Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt6-3D.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import collections, re, typing

try:
    from warnings import deprecated
except ImportError:
    pass

import PyQt6.sip

from PyQt6 import QtCore
from PyQt6 import QtGui
from PyQt6 import Qt3DCore
from PyQt6 import Qt3DInput
from PyQt6 import QtOpenGL
from PyQt6 import Qt3DRender

# Support for QDate, QDateTime and QTime.
import datetime

# Convenient type aliases.
PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[collections.abc.Callable[..., Any], QtCore.pyqtBoundSignal]


class QAbstractCameraController(Qt3DCore.QEntity):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    def mouseDevice(self) -> Qt3DInput.QMouseDevice|None: ...
    def keyboardDevice(self) -> Qt3DInput.QKeyboardDevice|None: ...
    decelerationChanged: typing.ClassVar[QtCore.pyqtSignal]
    accelerationChanged: typing.ClassVar[QtCore.pyqtSignal]
    lookSpeedChanged: typing.ClassVar[QtCore.pyqtSignal]
    linearSpeedChanged: typing.ClassVar[QtCore.pyqtSignal]
    cameraChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setDeceleration(self, deceleration: float) -> None: ...
    def setAcceleration(self, acceleration: float) -> None: ...
    def setLookSpeed(self, lookSpeed: float) -> None: ...
    def setLinearSpeed(self, linearSpeed: float) -> None: ...
    def setCamera(self, camera: Qt3DRender.QCamera|None) -> None: ...
    def deceleration(self) -> float: ...
    def acceleration(self) -> float: ...
    def lookSpeed(self) -> float: ...
    def linearSpeed(self) -> float: ...
    def camera(self) -> Qt3DRender.QCamera|None: ...


class QAbstractSpriteSheet(Qt3DCore.QNode):

    currentIndexChanged: typing.ClassVar[QtCore.pyqtSignal]
    textureTransformChanged: typing.ClassVar[QtCore.pyqtSignal]
    textureChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setCurrentIndex(self, currentIndex: int) -> None: ...
    def setTexture(self, texture: Qt3DRender.QAbstractTexture|None) -> None: ...
    def currentIndex(self) -> int: ...
    def textureTransform(self) -> QtGui.QMatrix3x3: ...
    def texture(self) -> Qt3DRender.QAbstractTexture|None: ...


class QConeGeometry(Qt3DCore.QGeometry):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    lengthChanged: typing.ClassVar[QtCore.pyqtSignal]
    slicesChanged: typing.ClassVar[QtCore.pyqtSignal]
    ringsChanged: typing.ClassVar[QtCore.pyqtSignal]
    bottomRadiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    topRadiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    hasBottomEndcapChanged: typing.ClassVar[QtCore.pyqtSignal]
    hasTopEndcapChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setLength(self, length: float) -> None: ...
    def setSlices(self, slices: int) -> None: ...
    def setRings(self, rings: int) -> None: ...
    def setBottomRadius(self, bottomRadius: float) -> None: ...
    def setTopRadius(self, topRadius: float) -> None: ...
    def setHasBottomEndcap(self, hasBottomEndcap: bool) -> None: ...
    def setHasTopEndcap(self, hasTopEndcap: bool) -> None: ...
    def indexAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def texCoordAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def normalAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def positionAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def length(self) -> float: ...
    def slices(self) -> int: ...
    def rings(self) -> int: ...
    def bottomRadius(self) -> float: ...
    def topRadius(self) -> float: ...
    def hasBottomEndcap(self) -> bool: ...
    def hasTopEndcap(self) -> bool: ...
    def updateIndices(self) -> None: ...
    def updateVertices(self) -> None: ...


class QConeGeometryView(Qt3DCore.QGeometryView):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    lengthChanged: typing.ClassVar[QtCore.pyqtSignal]
    slicesChanged: typing.ClassVar[QtCore.pyqtSignal]
    ringsChanged: typing.ClassVar[QtCore.pyqtSignal]
    bottomRadiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    topRadiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    hasBottomEndcapChanged: typing.ClassVar[QtCore.pyqtSignal]
    hasTopEndcapChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setLength(self, length: float) -> None: ...
    def setSlices(self, slices: int) -> None: ...
    def setRings(self, rings: int) -> None: ...
    def setBottomRadius(self, bottomRadius: float) -> None: ...
    def setTopRadius(self, topRadius: float) -> None: ...
    def setHasBottomEndcap(self, hasBottomEndcap: bool) -> None: ...
    def setHasTopEndcap(self, hasTopEndcap: bool) -> None: ...
    def length(self) -> float: ...
    def bottomRadius(self) -> float: ...
    def topRadius(self) -> float: ...
    def hasBottomEndcap(self) -> bool: ...
    def hasTopEndcap(self) -> bool: ...
    def slices(self) -> int: ...
    def rings(self) -> int: ...


class QConeMesh(Qt3DRender.QGeometryRenderer):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    lengthChanged: typing.ClassVar[QtCore.pyqtSignal]
    slicesChanged: typing.ClassVar[QtCore.pyqtSignal]
    ringsChanged: typing.ClassVar[QtCore.pyqtSignal]
    bottomRadiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    topRadiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    hasBottomEndcapChanged: typing.ClassVar[QtCore.pyqtSignal]
    hasTopEndcapChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setLength(self, length: float) -> None: ...
    def setSlices(self, slices: int) -> None: ...
    def setRings(self, rings: int) -> None: ...
    def setBottomRadius(self, bottomRadius: float) -> None: ...
    def setTopRadius(self, topRadius: float) -> None: ...
    def setHasBottomEndcap(self, hasBottomEndcap: bool) -> None: ...
    def setHasTopEndcap(self, hasTopEndcap: bool) -> None: ...
    def length(self) -> float: ...
    def bottomRadius(self) -> float: ...
    def topRadius(self) -> float: ...
    def hasBottomEndcap(self) -> bool: ...
    def hasTopEndcap(self) -> bool: ...
    def slices(self) -> int: ...
    def rings(self) -> int: ...


class QCuboidGeometry(Qt3DCore.QGeometry):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    xyMeshResolutionChanged: typing.ClassVar[QtCore.pyqtSignal]
    xzMeshResolutionChanged: typing.ClassVar[QtCore.pyqtSignal]
    yzMeshResolutionChanged: typing.ClassVar[QtCore.pyqtSignal]
    zExtentChanged: typing.ClassVar[QtCore.pyqtSignal]
    yExtentChanged: typing.ClassVar[QtCore.pyqtSignal]
    xExtentChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setXYMeshResolution(self, resolution: QtCore.QSize) -> None: ...
    def setXZMeshResolution(self, resolution: QtCore.QSize) -> None: ...
    def setYZMeshResolution(self, resolution: QtCore.QSize) -> None: ...
    def setZExtent(self, zExtent: float) -> None: ...
    def setYExtent(self, yExtent: float) -> None: ...
    def setXExtent(self, xExtent: float) -> None: ...
    def indexAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def tangentAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def texCoordAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def normalAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def positionAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def xzMeshResolution(self) -> QtCore.QSize: ...
    def xyMeshResolution(self) -> QtCore.QSize: ...
    def yzMeshResolution(self) -> QtCore.QSize: ...
    def zExtent(self) -> float: ...
    def yExtent(self) -> float: ...
    def xExtent(self) -> float: ...
    def updateVertices(self) -> None: ...
    def updateIndices(self) -> None: ...


class QCuboidGeometryView(Qt3DCore.QGeometryView):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    xyMeshResolutionChanged: typing.ClassVar[QtCore.pyqtSignal]
    xzMeshResolutionChanged: typing.ClassVar[QtCore.pyqtSignal]
    yzMeshResolutionChanged: typing.ClassVar[QtCore.pyqtSignal]
    zExtentChanged: typing.ClassVar[QtCore.pyqtSignal]
    yExtentChanged: typing.ClassVar[QtCore.pyqtSignal]
    xExtentChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setXYMeshResolution(self, resolution: QtCore.QSize) -> None: ...
    def setXZMeshResolution(self, resolution: QtCore.QSize) -> None: ...
    def setYZMeshResolution(self, resolution: QtCore.QSize) -> None: ...
    def setZExtent(self, zExtent: float) -> None: ...
    def setYExtent(self, yExtent: float) -> None: ...
    def setXExtent(self, xExtent: float) -> None: ...
    def xyMeshResolution(self) -> QtCore.QSize: ...
    def xzMeshResolution(self) -> QtCore.QSize: ...
    def yzMeshResolution(self) -> QtCore.QSize: ...
    def zExtent(self) -> float: ...
    def yExtent(self) -> float: ...
    def xExtent(self) -> float: ...


class QCuboidMesh(Qt3DRender.QGeometryRenderer):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    xyMeshResolutionChanged: typing.ClassVar[QtCore.pyqtSignal]
    xzMeshResolutionChanged: typing.ClassVar[QtCore.pyqtSignal]
    yzMeshResolutionChanged: typing.ClassVar[QtCore.pyqtSignal]
    zExtentChanged: typing.ClassVar[QtCore.pyqtSignal]
    yExtentChanged: typing.ClassVar[QtCore.pyqtSignal]
    xExtentChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setXYMeshResolution(self, resolution: QtCore.QSize) -> None: ...
    def setXZMeshResolution(self, resolution: QtCore.QSize) -> None: ...
    def setYZMeshResolution(self, resolution: QtCore.QSize) -> None: ...
    def setZExtent(self, zExtent: float) -> None: ...
    def setYExtent(self, yExtent: float) -> None: ...
    def setXExtent(self, xExtent: float) -> None: ...
    def xyMeshResolution(self) -> QtCore.QSize: ...
    def xzMeshResolution(self) -> QtCore.QSize: ...
    def yzMeshResolution(self) -> QtCore.QSize: ...
    def zExtent(self) -> float: ...
    def yExtent(self) -> float: ...
    def xExtent(self) -> float: ...


class QCylinderGeometry(Qt3DCore.QGeometry):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    lengthChanged: typing.ClassVar[QtCore.pyqtSignal]
    slicesChanged: typing.ClassVar[QtCore.pyqtSignal]
    ringsChanged: typing.ClassVar[QtCore.pyqtSignal]
    radiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setLength(self, length: float) -> None: ...
    def setRadius(self, radius: float) -> None: ...
    def setSlices(self, slices: int) -> None: ...
    def setRings(self, rings: int) -> None: ...
    def indexAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def texCoordAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def normalAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def positionAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def length(self) -> float: ...
    def radius(self) -> float: ...
    def slices(self) -> int: ...
    def rings(self) -> int: ...
    def updateIndices(self) -> None: ...
    def updateVertices(self) -> None: ...


class QCylinderGeometryView(Qt3DCore.QGeometryView):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    lengthChanged: typing.ClassVar[QtCore.pyqtSignal]
    slicesChanged: typing.ClassVar[QtCore.pyqtSignal]
    ringsChanged: typing.ClassVar[QtCore.pyqtSignal]
    radiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setLength(self, length: float) -> None: ...
    def setRadius(self, radius: float) -> None: ...
    def setSlices(self, slices: int) -> None: ...
    def setRings(self, rings: int) -> None: ...
    def length(self) -> float: ...
    def radius(self) -> float: ...
    def slices(self) -> int: ...
    def rings(self) -> int: ...


class QCylinderMesh(Qt3DRender.QGeometryRenderer):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    lengthChanged: typing.ClassVar[QtCore.pyqtSignal]
    slicesChanged: typing.ClassVar[QtCore.pyqtSignal]
    ringsChanged: typing.ClassVar[QtCore.pyqtSignal]
    radiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setLength(self, length: float) -> None: ...
    def setRadius(self, radius: float) -> None: ...
    def setSlices(self, slices: int) -> None: ...
    def setRings(self, rings: int) -> None: ...
    def length(self) -> float: ...
    def radius(self) -> float: ...
    def slices(self) -> int: ...
    def rings(self) -> int: ...


class QDiffuseMapMaterial(Qt3DRender.QMaterial):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    textureScaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    shininessChanged: typing.ClassVar[QtCore.pyqtSignal]
    specularChanged: typing.ClassVar[QtCore.pyqtSignal]
    diffuseChanged: typing.ClassVar[QtCore.pyqtSignal]
    ambientChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setTextureScale(self, textureScale: float) -> None: ...
    def setDiffuse(self, diffuse: Qt3DRender.QAbstractTexture|None) -> None: ...
    def setShininess(self, shininess: float) -> None: ...
    def setSpecular(self, specular: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setAmbient(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def textureScale(self) -> float: ...
    def diffuse(self) -> Qt3DRender.QAbstractTexture|None: ...
    def shininess(self) -> float: ...
    def specular(self) -> QtGui.QColor: ...
    def ambient(self) -> QtGui.QColor: ...


class QDiffuseSpecularMapMaterial(Qt3DRender.QMaterial):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    textureScaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    shininessChanged: typing.ClassVar[QtCore.pyqtSignal]
    specularChanged: typing.ClassVar[QtCore.pyqtSignal]
    diffuseChanged: typing.ClassVar[QtCore.pyqtSignal]
    ambientChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setTextureScale(self, textureScale: float) -> None: ...
    def setShininess(self, shininess: float) -> None: ...
    def setSpecular(self, specular: Qt3DRender.QAbstractTexture|None) -> None: ...
    def setDiffuse(self, diffuse: Qt3DRender.QAbstractTexture|None) -> None: ...
    def setAmbient(self, ambient: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def textureScale(self) -> float: ...
    def shininess(self) -> float: ...
    def specular(self) -> Qt3DRender.QAbstractTexture|None: ...
    def diffuse(self) -> Qt3DRender.QAbstractTexture|None: ...
    def ambient(self) -> QtGui.QColor: ...


class QDiffuseSpecularMaterial(Qt3DRender.QMaterial):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    alphaBlendingEnabledChanged: typing.ClassVar[QtCore.pyqtSignal]
    textureScaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    normalChanged: typing.ClassVar[QtCore.pyqtSignal]
    shininessChanged: typing.ClassVar[QtCore.pyqtSignal]
    specularChanged: typing.ClassVar[QtCore.pyqtSignal]
    diffuseChanged: typing.ClassVar[QtCore.pyqtSignal]
    ambientChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setAlphaBlendingEnabled(self, enabled: bool) -> None: ...
    def setTextureScale(self, textureScale: float) -> None: ...
    def setNormal(self, normal: typing.Any) -> None: ...
    def setShininess(self, shininess: float) -> None: ...
    def setSpecular(self, specular: typing.Any) -> None: ...
    def setDiffuse(self, diffuse: typing.Any) -> None: ...
    def setAmbient(self, ambient: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def isAlphaBlendingEnabled(self) -> bool: ...
    def textureScale(self) -> float: ...
    def normal(self) -> typing.Any: ...
    def shininess(self) -> float: ...
    def specular(self) -> typing.Any: ...
    def diffuse(self) -> typing.Any: ...
    def ambient(self) -> QtGui.QColor: ...


class QExtrudedTextGeometry(Qt3DCore.QGeometry):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    depthChanged: typing.ClassVar[QtCore.pyqtSignal]
    fontChanged: typing.ClassVar[QtCore.pyqtSignal]
    textChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setDepth(self, extrusionLength: float) -> None: ...
    def setFont(self, font: QtGui.QFont) -> None: ...
    def setText(self, text: str|None) -> None: ...
    def extrusionLength(self) -> float: ...
    def font(self) -> QtGui.QFont: ...
    def text(self) -> str: ...
    def indexAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def normalAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def positionAttribute(self) -> Qt3DCore.QAttribute|None: ...


class QExtrudedTextMesh(Qt3DRender.QGeometryRenderer):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    depthChanged: typing.ClassVar[QtCore.pyqtSignal]
    fontChanged: typing.ClassVar[QtCore.pyqtSignal]
    textChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setDepth(self, depth: float) -> None: ...
    def setFont(self, font: QtGui.QFont) -> None: ...
    def setText(self, text: str|None) -> None: ...
    def depth(self) -> float: ...
    def font(self) -> QtGui.QFont: ...
    def text(self) -> str: ...


class QFirstPersonCameraController('QAbstractCameraController'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...


class QForwardRenderer(Qt3DRender.QTechniqueFilter):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    showDebugOverlayChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setShowDebugOverlay(self, showDebugOverlay: bool) -> None: ...
    def showDebugOverlay(self) -> bool: ...
    buffersToClearChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setBuffersToClear(self, a0: Qt3DRender.QClearBuffers.BufferType) -> None: ...
    def buffersToClear(self) -> Qt3DRender.QClearBuffers.BufferType: ...
    gammaChanged: typing.ClassVar[QtCore.pyqtSignal]
    frustumCullingEnabledChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setGamma(self, gamma: float) -> None: ...
    def setFrustumCullingEnabled(self, enabled: bool) -> None: ...
    def gamma(self) -> float: ...
    def isFrustumCullingEnabled(self) -> bool: ...
    externalRenderTargetSizeChanged: typing.ClassVar[QtCore.pyqtSignal]
    surfaceChanged: typing.ClassVar[QtCore.pyqtSignal]
    cameraChanged: typing.ClassVar[QtCore.pyqtSignal]
    clearColorChanged: typing.ClassVar[QtCore.pyqtSignal]
    viewportRectChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setExternalRenderTargetSize(self, size: QtCore.QSize) -> None: ...
    def setSurface(self, surface: QtCore.QObject|None) -> None: ...
    def setCamera(self, camera: Qt3DCore.QEntity|None) -> None: ...
    def setClearColor(self, clearColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setViewportRect(self, viewportRect: QtCore.QRectF) -> None: ...
    def externalRenderTargetSize(self) -> QtCore.QSize: ...
    def surface(self) -> QtCore.QObject|None: ...
    def camera(self) -> Qt3DCore.QEntity|None: ...
    def clearColor(self) -> QtGui.QColor: ...
    def viewportRect(self) -> QtCore.QRectF: ...


class QGoochMaterial(Qt3DRender.QMaterial):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    shininessChanged: typing.ClassVar[QtCore.pyqtSignal]
    betaChanged: typing.ClassVar[QtCore.pyqtSignal]
    alphaChanged: typing.ClassVar[QtCore.pyqtSignal]
    warmChanged: typing.ClassVar[QtCore.pyqtSignal]
    coolChanged: typing.ClassVar[QtCore.pyqtSignal]
    specularChanged: typing.ClassVar[QtCore.pyqtSignal]
    diffuseChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setShininess(self, shininess: float) -> None: ...
    def setBeta(self, beta: float) -> None: ...
    def setAlpha(self, alpha: float) -> None: ...
    def setWarm(self, warm: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setCool(self, cool: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setSpecular(self, specular: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setDiffuse(self, diffuse: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def shininess(self) -> float: ...
    def beta(self) -> float: ...
    def alpha(self) -> float: ...
    def warm(self) -> QtGui.QColor: ...
    def cool(self) -> QtGui.QColor: ...
    def specular(self) -> QtGui.QColor: ...
    def diffuse(self) -> QtGui.QColor: ...


class QMetalRoughMaterial(Qt3DRender.QMaterial):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    textureScaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    normalChanged: typing.ClassVar[QtCore.pyqtSignal]
    ambientOcclusionChanged: typing.ClassVar[QtCore.pyqtSignal]
    roughnessChanged: typing.ClassVar[QtCore.pyqtSignal]
    metalnessChanged: typing.ClassVar[QtCore.pyqtSignal]
    baseColorChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setTextureScale(self, textureScale: float) -> None: ...
    def setNormal(self, normal: typing.Any) -> None: ...
    def setAmbientOcclusion(self, ambientOcclusion: typing.Any) -> None: ...
    def setRoughness(self, roughness: typing.Any) -> None: ...
    def setMetalness(self, metalness: typing.Any) -> None: ...
    def setBaseColor(self, baseColor: typing.Any) -> None: ...
    def textureScale(self) -> float: ...
    def normal(self) -> typing.Any: ...
    def ambientOcclusion(self) -> typing.Any: ...
    def roughness(self) -> typing.Any: ...
    def metalness(self) -> typing.Any: ...
    def baseColor(self) -> typing.Any: ...


class QMorphPhongMaterial(Qt3DRender.QMaterial):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    interpolatorChanged: typing.ClassVar[QtCore.pyqtSignal]
    shininessChanged: typing.ClassVar[QtCore.pyqtSignal]
    specularChanged: typing.ClassVar[QtCore.pyqtSignal]
    diffuseChanged: typing.ClassVar[QtCore.pyqtSignal]
    ambientChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setInterpolator(self, interpolator: float) -> None: ...
    def setShininess(self, shininess: float) -> None: ...
    def setSpecular(self, specular: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setDiffuse(self, diffuse: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setAmbient(self, ambient: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def interpolator(self) -> float: ...
    def shininess(self) -> float: ...
    def specular(self) -> QtGui.QColor: ...
    def diffuse(self) -> QtGui.QColor: ...
    def ambient(self) -> QtGui.QColor: ...


class QNormalDiffuseMapMaterial(Qt3DRender.QMaterial):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    textureScaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    shininessChanged: typing.ClassVar[QtCore.pyqtSignal]
    specularChanged: typing.ClassVar[QtCore.pyqtSignal]
    normalChanged: typing.ClassVar[QtCore.pyqtSignal]
    diffuseChanged: typing.ClassVar[QtCore.pyqtSignal]
    ambientChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setTextureScale(self, textureScale: float) -> None: ...
    def setShininess(self, shininess: float) -> None: ...
    def setNormal(self, normal: Qt3DRender.QAbstractTexture|None) -> None: ...
    def setDiffuse(self, diffuse: Qt3DRender.QAbstractTexture|None) -> None: ...
    def setSpecular(self, specular: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setAmbient(self, ambient: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def textureScale(self) -> float: ...
    def shininess(self) -> float: ...
    def normal(self) -> Qt3DRender.QAbstractTexture|None: ...
    def diffuse(self) -> Qt3DRender.QAbstractTexture|None: ...
    def specular(self) -> QtGui.QColor: ...
    def ambient(self) -> QtGui.QColor: ...


class QNormalDiffuseMapAlphaMaterial('QNormalDiffuseMapMaterial'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...


class QNormalDiffuseSpecularMapMaterial(Qt3DRender.QMaterial):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    textureScaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    shininessChanged: typing.ClassVar[QtCore.pyqtSignal]
    specularChanged: typing.ClassVar[QtCore.pyqtSignal]
    normalChanged: typing.ClassVar[QtCore.pyqtSignal]
    diffuseChanged: typing.ClassVar[QtCore.pyqtSignal]
    ambientChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setTextureScale(self, textureScale: float) -> None: ...
    def setShininess(self, shininess: float) -> None: ...
    def setSpecular(self, specular: Qt3DRender.QAbstractTexture|None) -> None: ...
    def setNormal(self, normal: Qt3DRender.QAbstractTexture|None) -> None: ...
    def setDiffuse(self, diffuse: Qt3DRender.QAbstractTexture|None) -> None: ...
    def setAmbient(self, ambient: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def textureScale(self) -> float: ...
    def shininess(self) -> float: ...
    def specular(self) -> Qt3DRender.QAbstractTexture|None: ...
    def normal(self) -> Qt3DRender.QAbstractTexture|None: ...
    def diffuse(self) -> Qt3DRender.QAbstractTexture|None: ...
    def ambient(self) -> QtGui.QColor: ...


class QOrbitCameraController('QAbstractCameraController'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    zoomTranslateViewCenterChanged: typing.ClassVar[QtCore.pyqtSignal]
    inverseTiltChanged: typing.ClassVar[QtCore.pyqtSignal]
    inversePanChanged: typing.ClassVar[QtCore.pyqtSignal]
    inverseYTranslateChanged: typing.ClassVar[QtCore.pyqtSignal]
    inverseXTranslateChanged: typing.ClassVar[QtCore.pyqtSignal]
    upVectorChanged: typing.ClassVar[QtCore.pyqtSignal]
    zoomInLimitChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setZoomTranslateViewCenter(self, isTranslate: bool) -> None: ...
    def setInverseTilt(self, isInverse: bool) -> None: ...
    def setInversePan(self, isInverse: bool) -> None: ...
    def setInverseYTranslate(self, isInverse: bool) -> None: ...
    def setInverseXTranslate(self, isInverse: bool) -> None: ...
    def setUpVector(self, upVector: QtGui.QVector3D) -> None: ...
    def setZoomInLimit(self, zoomInLimit: float) -> None: ...
    def zoomTranslateViewCenter(self) -> bool: ...
    def inverseTilt(self) -> bool: ...
    def inversePan(self) -> bool: ...
    def inverseYTranslate(self) -> bool: ...
    def inverseXTranslate(self) -> bool: ...
    def upVector(self) -> QtGui.QVector3D: ...
    def zoomInLimit(self) -> float: ...


class QPerVertexColorMaterial(Qt3DRender.QMaterial):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...


class QPhongAlphaMaterial(Qt3DRender.QMaterial):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    blendFunctionArgChanged: typing.ClassVar[QtCore.pyqtSignal]
    destinationAlphaArgChanged: typing.ClassVar[QtCore.pyqtSignal]
    sourceAlphaArgChanged: typing.ClassVar[QtCore.pyqtSignal]
    destinationRgbArgChanged: typing.ClassVar[QtCore.pyqtSignal]
    sourceRgbArgChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setBlendFunctionArg(self, blendFunctionArg: Qt3DRender.QBlendEquation.BlendFunction) -> None: ...
    def setDestinationAlphaArg(self, destinationAlphaArg: Qt3DRender.QBlendEquationArguments.Blending) -> None: ...
    def setSourceAlphaArg(self, sourceAlphaArg: Qt3DRender.QBlendEquationArguments.Blending) -> None: ...
    def setDestinationRgbArg(self, destinationRgbArg: Qt3DRender.QBlendEquationArguments.Blending) -> None: ...
    def setSourceRgbArg(self, sourceRgbArg: Qt3DRender.QBlendEquationArguments.Blending) -> None: ...
    def blendFunctionArg(self) -> Qt3DRender.QBlendEquation.BlendFunction: ...
    def destinationAlphaArg(self) -> Qt3DRender.QBlendEquationArguments.Blending: ...
    def sourceAlphaArg(self) -> Qt3DRender.QBlendEquationArguments.Blending: ...
    def destinationRgbArg(self) -> Qt3DRender.QBlendEquationArguments.Blending: ...
    def sourceRgbArg(self) -> Qt3DRender.QBlendEquationArguments.Blending: ...
    alphaChanged: typing.ClassVar[QtCore.pyqtSignal]
    shininessChanged: typing.ClassVar[QtCore.pyqtSignal]
    specularChanged: typing.ClassVar[QtCore.pyqtSignal]
    diffuseChanged: typing.ClassVar[QtCore.pyqtSignal]
    ambientChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setAlpha(self, alpha: float) -> None: ...
    def setShininess(self, shininess: float) -> None: ...
    def setSpecular(self, specular: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setDiffuse(self, diffuse: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setAmbient(self, ambient: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def alpha(self) -> float: ...
    def shininess(self) -> float: ...
    def specular(self) -> QtGui.QColor: ...
    def diffuse(self) -> QtGui.QColor: ...
    def ambient(self) -> QtGui.QColor: ...


class QPhongMaterial(Qt3DRender.QMaterial):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    shininessChanged: typing.ClassVar[QtCore.pyqtSignal]
    specularChanged: typing.ClassVar[QtCore.pyqtSignal]
    diffuseChanged: typing.ClassVar[QtCore.pyqtSignal]
    ambientChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setShininess(self, shininess: float) -> None: ...
    def setSpecular(self, specular: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setDiffuse(self, diffuse: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setAmbient(self, ambient: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def shininess(self) -> float: ...
    def specular(self) -> QtGui.QColor: ...
    def diffuse(self) -> QtGui.QColor: ...
    def ambient(self) -> QtGui.QColor: ...


class QPlaneGeometry(Qt3DCore.QGeometry):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    mirroredChanged: typing.ClassVar[QtCore.pyqtSignal]
    heightChanged: typing.ClassVar[QtCore.pyqtSignal]
    widthChanged: typing.ClassVar[QtCore.pyqtSignal]
    resolutionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setMirrored(self, mirrored: bool) -> None: ...
    def setHeight(self, height: float) -> None: ...
    def setWidth(self, width: float) -> None: ...
    def setResolution(self, resolution: QtCore.QSize) -> None: ...
    def indexAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def tangentAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def texCoordAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def normalAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def positionAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def mirrored(self) -> bool: ...
    def height(self) -> float: ...
    def width(self) -> float: ...
    def resolution(self) -> QtCore.QSize: ...
    def updateIndices(self) -> None: ...
    def updateVertices(self) -> None: ...


class QPlaneGeometryView(Qt3DCore.QGeometryView):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    mirroredChanged: typing.ClassVar[QtCore.pyqtSignal]
    heightChanged: typing.ClassVar[QtCore.pyqtSignal]
    widthChanged: typing.ClassVar[QtCore.pyqtSignal]
    meshResolutionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setMirrored(self, mirrored: bool) -> None: ...
    def setMeshResolution(self, resolution: QtCore.QSize) -> None: ...
    def setHeight(self, height: float) -> None: ...
    def setWidth(self, width: float) -> None: ...
    def mirrored(self) -> bool: ...
    def meshResolution(self) -> QtCore.QSize: ...
    def height(self) -> float: ...
    def width(self) -> float: ...


class QPlaneMesh(Qt3DRender.QGeometryRenderer):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    mirroredChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setMirrored(self, mirrored: bool) -> None: ...
    def mirrored(self) -> bool: ...
    heightChanged: typing.ClassVar[QtCore.pyqtSignal]
    widthChanged: typing.ClassVar[QtCore.pyqtSignal]
    meshResolutionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setMeshResolution(self, resolution: QtCore.QSize) -> None: ...
    def setHeight(self, height: float) -> None: ...
    def setWidth(self, width: float) -> None: ...
    def meshResolution(self) -> QtCore.QSize: ...
    def height(self) -> float: ...
    def width(self) -> float: ...


class QSkyboxEntity(Qt3DCore.QEntity):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    gammaCorrectEnabledChanged: typing.ClassVar[QtCore.pyqtSignal]
    baseNameChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setGammaCorrectEnabled(self, enabled: bool) -> None: ...
    def isGammaCorrectEnabled(self) -> bool: ...
    extensionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def extension(self) -> str: ...
    def setExtension(self, extension: str|None) -> None: ...
    def baseName(self) -> str: ...
    def setBaseName(self, path: str|None) -> None: ...


class QSphereGeometry(Qt3DCore.QGeometry):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    generateTangentsChanged: typing.ClassVar[QtCore.pyqtSignal]
    slicesChanged: typing.ClassVar[QtCore.pyqtSignal]
    ringsChanged: typing.ClassVar[QtCore.pyqtSignal]
    radiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setGenerateTangents(self, gen: bool) -> None: ...
    def setRadius(self, radius: float) -> None: ...
    def setSlices(self, slices: int) -> None: ...
    def setRings(self, rings: int) -> None: ...
    def indexAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def tangentAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def texCoordAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def normalAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def positionAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def radius(self) -> float: ...
    def slices(self) -> int: ...
    def rings(self) -> int: ...
    def generateTangents(self) -> bool: ...
    def updateIndices(self) -> None: ...
    def updateVertices(self) -> None: ...


class QSphereGeometryView(Qt3DCore.QGeometryView):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    generateTangentsChanged: typing.ClassVar[QtCore.pyqtSignal]
    slicesChanged: typing.ClassVar[QtCore.pyqtSignal]
    ringsChanged: typing.ClassVar[QtCore.pyqtSignal]
    radiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setGenerateTangents(self, gen: bool) -> None: ...
    def setRadius(self, radius: float) -> None: ...
    def setSlices(self, slices: int) -> None: ...
    def setRings(self, rings: int) -> None: ...
    def generateTangents(self) -> bool: ...
    def radius(self) -> float: ...
    def slices(self) -> int: ...
    def rings(self) -> int: ...


class QSphereMesh(Qt3DRender.QGeometryRenderer):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    generateTangentsChanged: typing.ClassVar[QtCore.pyqtSignal]
    slicesChanged: typing.ClassVar[QtCore.pyqtSignal]
    ringsChanged: typing.ClassVar[QtCore.pyqtSignal]
    radiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setGenerateTangents(self, gen: bool) -> None: ...
    def setRadius(self, radius: float) -> None: ...
    def setSlices(self, slices: int) -> None: ...
    def setRings(self, rings: int) -> None: ...
    def generateTangents(self) -> bool: ...
    def radius(self) -> float: ...
    def slices(self) -> int: ...
    def rings(self) -> int: ...


class QSpriteGrid('QAbstractSpriteSheet'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    columnsChanged: typing.ClassVar[QtCore.pyqtSignal]
    rowsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setColumns(self, columns: int) -> None: ...
    def setRows(self, rows: int) -> None: ...
    def columns(self) -> int: ...
    def rows(self) -> int: ...


class QSpriteSheet('QAbstractSpriteSheet'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    spritesChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setSprites(self, sprites: collections.abc.Iterable['QSpriteSheetItem']) -> None: ...
    def removeSprite(self, sprite: 'QSpriteSheetItem|None') -> None: ...
    @typing.overload
    def addSprite(self, x: int, y: int, width: int, height: int) -> 'QSpriteSheetItem|None': ...
    @typing.overload
    def addSprite(self, sprite: 'QSpriteSheetItem|None') -> None: ...
    def sprites(self) -> list['QSpriteSheetItem']: ...


class QSpriteSheetItem(Qt3DCore.QNode):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    heightChanged: typing.ClassVar[QtCore.pyqtSignal]
    widthChanged: typing.ClassVar[QtCore.pyqtSignal]
    yChanged: typing.ClassVar[QtCore.pyqtSignal]
    xChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setHeight(self, height: int) -> None: ...
    def setWidth(self, width: int) -> None: ...
    def setY(self, y: int) -> None: ...
    def setX(self, x: int) -> None: ...
    def height(self) -> int: ...
    def width(self) -> int: ...
    def y(self) -> int: ...
    def x(self) -> int: ...


class Qt3DWindow(QtGui.QWindow):

    def __init__(self, screen: QtGui.QScreen|None = ..., api: Qt3DRender.API = ...) -> None: ...

    def event(self, e: QtCore.QEvent|None) -> bool: ...
    def resizeEvent(self, a0: QtGui.QResizeEvent|None) -> None: ...
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    def renderSettings(self) -> Qt3DRender.QRenderSettings|None: ...
    def camera(self) -> Qt3DRender.QCamera|None: ...
    def defaultFrameGraph(self) -> 'QForwardRenderer|None': ...
    def activeFrameGraph(self) -> Qt3DRender.QFrameGraphNode|None: ...
    def setActiveFrameGraph(self, activeFrameGraph: Qt3DRender.QFrameGraphNode|None) -> None: ...
    def setRootEntity(self, root: Qt3DCore.QEntity|None) -> None: ...
    @typing.overload
    def registerAspect(self, aspect: Qt3DCore.QAbstractAspect|None) -> None: ...
    @typing.overload
    def registerAspect(self, name: str|None) -> None: ...


class QText2DEntity(Qt3DCore.QEntity):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    def setAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def alignment(self) -> QtCore.Qt.AlignmentFlag: ...
    heightChanged: typing.ClassVar[QtCore.pyqtSignal]
    widthChanged: typing.ClassVar[QtCore.pyqtSignal]
    textChanged: typing.ClassVar[QtCore.pyqtSignal]
    colorChanged: typing.ClassVar[QtCore.pyqtSignal]
    fontChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setHeight(self, height: float) -> None: ...
    def setWidth(self, width: float) -> None: ...
    def height(self) -> float: ...
    def width(self) -> float: ...
    def setText(self, text: str|None) -> None: ...
    def text(self) -> str: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setFont(self, font: QtGui.QFont) -> None: ...
    def font(self) -> QtGui.QFont: ...


class QTextureMaterial(Qt3DRender.QMaterial):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    alphaBlendingEnabledChanged: typing.ClassVar[QtCore.pyqtSignal]
    textureTransformChanged: typing.ClassVar[QtCore.pyqtSignal]
    textureOffsetChanged: typing.ClassVar[QtCore.pyqtSignal]
    textureChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setAlphaBlendingEnabled(self, enabled: bool) -> None: ...
    def setTextureTransform(self, matrix: QtGui.QMatrix3x3) -> None: ...
    def setTextureOffset(self, textureOffset: QtGui.QVector2D) -> None: ...
    def setTexture(self, texture: Qt3DRender.QAbstractTexture|None) -> None: ...
    def isAlphaBlendingEnabled(self) -> bool: ...
    def textureTransform(self) -> QtGui.QMatrix3x3: ...
    def textureOffset(self) -> QtGui.QVector2D: ...
    def texture(self) -> Qt3DRender.QAbstractTexture|None: ...


class QTorusGeometry(Qt3DCore.QGeometry):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    minorRadiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    slicesChanged: typing.ClassVar[QtCore.pyqtSignal]
    ringsChanged: typing.ClassVar[QtCore.pyqtSignal]
    radiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setMinorRadius(self, minorRadius: float) -> None: ...
    def setRadius(self, radius: float) -> None: ...
    def setSlices(self, slices: int) -> None: ...
    def setRings(self, rings: int) -> None: ...
    def indexAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def texCoordAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def normalAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def positionAttribute(self) -> Qt3DCore.QAttribute|None: ...
    def minorRadius(self) -> float: ...
    def radius(self) -> float: ...
    def slices(self) -> int: ...
    def rings(self) -> int: ...
    def updateIndices(self) -> None: ...
    def updateVertices(self) -> None: ...


class QTorusGeometryView(Qt3DCore.QGeometryView):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    minorRadiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    slicesChanged: typing.ClassVar[QtCore.pyqtSignal]
    ringsChanged: typing.ClassVar[QtCore.pyqtSignal]
    radiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setMinorRadius(self, minorRadius: float) -> None: ...
    def setRadius(self, radius: float) -> None: ...
    def setSlices(self, slices: int) -> None: ...
    def setRings(self, rings: int) -> None: ...
    def minorRadius(self) -> float: ...
    def radius(self) -> float: ...
    def slices(self) -> int: ...
    def rings(self) -> int: ...


class QTorusMesh(Qt3DRender.QGeometryRenderer):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    minorRadiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    slicesChanged: typing.ClassVar[QtCore.pyqtSignal]
    ringsChanged: typing.ClassVar[QtCore.pyqtSignal]
    radiusChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setMinorRadius(self, minorRadius: float) -> None: ...
    def setRadius(self, radius: float) -> None: ...
    def setSlices(self, slices: int) -> None: ...
    def setRings(self, rings: int) -> None: ...
    def minorRadius(self) -> float: ...
    def radius(self) -> float: ...
    def slices(self) -> int: ...
    def rings(self) -> int: ...


def setupWindowSurface(window: QtGui.QWindow|None, a1: Qt3DRender.API) -> None: ...



# The PEP 484 type hints stub file for the Qt3DLogic module.
#
# Generated by SIP 6.15.1.dev0+g7378531ef.d20251218
#
# Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt6-3D.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import collections, re, typing

try:
    from warnings import deprecated
except ImportError:
    pass

import PyQt6.sip

from PyQt6 import QtCore
from PyQt6 import QtGui
from PyQt6 import Qt3DCore

# Support for QDate, QDateTime and QTime.
import datetime

# Convenient type aliases.
PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[collections.abc.Callable[..., Any], QtCore.pyqtBoundSignal]


class QFrameAction(Qt3DCore.QComponent):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    triggered: typing.ClassVar[QtCore.pyqtSignal]


class QLogicAspect(Qt3DCore.QAbstractAspect):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...



# The PEP 484 type hints stub file for the Qt3DAnimation module.
#
# Generated by SIP 6.15.1.dev0+g7378531ef.d20251218
#
# Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt6-3D.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import collections, re, typing, enum

try:
    from warnings import deprecated
except ImportError:
    pass

import PyQt6.sip

from PyQt6 import QtCore
from PyQt6 import QtGui
from PyQt6 import Qt3DCore
from PyQt6 import QtOpenGL
from PyQt6 import Qt3DRender

# Support for QDate, QDateTime and QTime.
import datetime

# Convenient type aliases.
PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[collections.abc.Callable[..., Any], QtCore.pyqtBoundSignal]


class QAbstractAnimation(QtCore.QObject):

    class AnimationType(enum.Enum):
        KeyframeAnimation = ... # type: QAbstractAnimation.AnimationType
        MorphingAnimation = ... # type: QAbstractAnimation.AnimationType
        VertexBlendAnimation = ... # type: QAbstractAnimation.AnimationType

    durationChanged: typing.ClassVar[QtCore.pyqtSignal]
    positionChanged: typing.ClassVar[QtCore.pyqtSignal]
    animationNameChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setDuration(self, duration: float) -> None: ...
    def setPosition(self, position: float) -> None: ...
    def setAnimationName(self, name: str|None) -> None: ...
    def duration(self) -> float: ...
    def position(self) -> float: ...
    def animationType(self) -> 'QAbstractAnimation.AnimationType': ...
    def animationName(self) -> str: ...


class QAbstractAnimationClip(Qt3DCore.QNode):

    durationChanged: typing.ClassVar[QtCore.pyqtSignal]
    def duration(self) -> float: ...


class QAbstractChannelMapping(Qt3DCore.QNode): ...


class QAbstractClipAnimator(Qt3DCore.QComponent):

    class Loops(enum.Enum):
        Infinite = ... # type: QAbstractClipAnimator.Loops

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    normalizedTimeChanged: typing.ClassVar[QtCore.pyqtSignal]
    clockChanged: typing.ClassVar[QtCore.pyqtSignal]
    loopCountChanged: typing.ClassVar[QtCore.pyqtSignal]
    channelMapperChanged: typing.ClassVar[QtCore.pyqtSignal]
    runningChanged: typing.ClassVar[QtCore.pyqtSignal]
    def stop(self) -> None: ...
    def start(self) -> None: ...
    def setNormalizedTime(self, timeFraction: float) -> None: ...
    def setClock(self, clock: 'QClock|None') -> None: ...
    def setLoopCount(self, loops: int) -> None: ...
    def setChannelMapper(self, channelMapper: 'QChannelMapper|None') -> None: ...
    def setRunning(self, running: bool) -> None: ...
    def normalizedTime(self) -> float: ...
    def clock(self) -> 'QClock|None': ...
    def loopCount(self) -> int: ...
    def channelMapper(self) -> 'QChannelMapper|None': ...
    def isRunning(self) -> bool: ...


class QAbstractClipBlendNode(Qt3DCore.QNode):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...


class QAdditiveClipBlend('QAbstractClipBlendNode'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    additiveClipChanged: typing.ClassVar[QtCore.pyqtSignal]
    baseClipChanged: typing.ClassVar[QtCore.pyqtSignal]
    additiveFactorChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setAdditiveClip(self, additiveClip: 'QAbstractClipBlendNode|None') -> None: ...
    def setBaseClip(self, baseClip: 'QAbstractClipBlendNode|None') -> None: ...
    def setAdditiveFactor(self, additiveFactor: float) -> None: ...
    def additiveClip(self) -> 'QAbstractClipBlendNode|None': ...
    def baseClip(self) -> 'QAbstractClipBlendNode|None': ...
    def additiveFactor(self) -> float: ...


class QAnimationAspect(Qt3DCore.QAbstractAspect):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...


class QAnimationClip('QAbstractAnimationClip'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    clipDataChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setClipData(self, clipData: 'QAnimationClipData') -> None: ...
    def clipData(self) -> 'QAnimationClipData': ...


class QAnimationClipData(PyQt6.sip.simplewrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QAnimationClipData') -> None: ...

    def isValid(self) -> bool: ...
    def clearChannels(self) -> None: ...
    def removeChannel(self, index: int) -> None: ...
    def insertChannel(self, index: int, c: 'QChannel') -> None: ...
    def appendChannel(self, c: 'QChannel') -> None: ...
    def channelCount(self) -> int: ...
    def name(self) -> str: ...
    def setName(self, name: str|None) -> None: ...


class QAnimationClipLoader('QAbstractAnimationClip'):

    class Status(enum.Enum):
        NotReady = ... # type: QAnimationClipLoader.Status
        Ready = ... # type: QAnimationClipLoader.Status
        Error = ... # type: QAnimationClipLoader.Status

    @typing.overload
    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...
    @typing.overload
    def __init__(self, source: QtCore.QUrl, parent: Qt3DCore.QNode|None = ...) -> None: ...

    statusChanged: typing.ClassVar[QtCore.pyqtSignal]
    sourceChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setSource(self, source: QtCore.QUrl) -> None: ...
    def status(self) -> 'QAnimationClipLoader.Status': ...
    def source(self) -> QtCore.QUrl: ...


class QAnimationController(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    recursiveChanged: typing.ClassVar[QtCore.pyqtSignal]
    entityChanged: typing.ClassVar[QtCore.pyqtSignal]
    positionOffsetChanged: typing.ClassVar[QtCore.pyqtSignal]
    positionScaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    positionChanged: typing.ClassVar[QtCore.pyqtSignal]
    activeAnimationGroupChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setRecursive(self, recursive: bool) -> None: ...
    def setEntity(self, entity: Qt3DCore.QEntity|None) -> None: ...
    def setPositionOffset(self, offset: float) -> None: ...
    def setPositionScale(self, scale: float) -> None: ...
    def setPosition(self, position: float) -> None: ...
    def setActiveAnimationGroup(self, index: int) -> None: ...
    def getGroup(self, index: int) -> 'QAnimationGroup|None': ...
    def getAnimationIndex(self, name: str|None) -> int: ...
    def removeAnimationGroup(self, animationGroups: 'QAnimationGroup|None') -> None: ...
    def addAnimationGroup(self, animationGroups: 'QAnimationGroup|None') -> None: ...
    def setAnimationGroups(self, animationGroups: collections.abc.Iterable['QAnimationGroup']) -> None: ...
    def recursive(self) -> bool: ...
    def entity(self) -> Qt3DCore.QEntity|None: ...
    def positionOffset(self) -> float: ...
    def positionScale(self) -> float: ...
    def position(self) -> float: ...
    def activeAnimationGroup(self) -> int: ...
    def animationGroupList(self) -> list['QAnimationGroup']: ...


class QAnimationGroup(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    durationChanged: typing.ClassVar[QtCore.pyqtSignal]
    positionChanged: typing.ClassVar[QtCore.pyqtSignal]
    nameChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setPosition(self, position: float) -> None: ...
    def setName(self, name: str|None) -> None: ...
    def removeAnimation(self, animation: 'QAbstractAnimation|None') -> None: ...
    def addAnimation(self, animation: 'QAbstractAnimation|None') -> None: ...
    def setAnimations(self, animations: collections.abc.Iterable['QAbstractAnimation']) -> None: ...
    def duration(self) -> float: ...
    def position(self) -> float: ...
    def animationList(self) -> list['QAbstractAnimation']: ...
    def name(self) -> str: ...


class QBlendedClipAnimator('QAbstractClipAnimator'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    blendTreeChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setBlendTree(self, blendTree: 'QAbstractClipBlendNode|None') -> None: ...
    def blendTree(self) -> 'QAbstractClipBlendNode|None': ...


class QChannel(PyQt6.sip.simplewrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, name: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QChannel') -> None: ...

    def clearChannelComponents(self) -> None: ...
    def removeChannelComponent(self, index: int) -> None: ...
    def insertChannelComponent(self, index: int, component: 'QChannelComponent') -> None: ...
    def appendChannelComponent(self, component: 'QChannelComponent') -> None: ...
    def channelComponentCount(self) -> int: ...
    def jointIndex(self) -> int: ...
    def setJointIndex(self, jointIndex: int) -> None: ...
    def name(self) -> str: ...
    def setName(self, name: str|None) -> None: ...


class QChannelComponent(PyQt6.sip.simplewrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, name: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QChannelComponent') -> None: ...

    def clearKeyFrames(self) -> None: ...
    def removeKeyFrame(self, index: int) -> None: ...
    def insertKeyFrame(self, index: int, kf: 'QKeyFrame') -> None: ...
    def appendKeyFrame(self, kf: 'QKeyFrame') -> None: ...
    def keyFrameCount(self) -> int: ...
    def name(self) -> str: ...
    def setName(self, name: str|None) -> None: ...


class QChannelMapper(Qt3DCore.QNode):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    def mappings(self) -> list['QAbstractChannelMapping']: ...
    def removeMapping(self, mapping: 'QAbstractChannelMapping|None') -> None: ...
    def addMapping(self, mapping: 'QAbstractChannelMapping|None') -> None: ...


class QChannelMapping('QAbstractChannelMapping'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    propertyChanged: typing.ClassVar[QtCore.pyqtSignal]
    targetChanged: typing.ClassVar[QtCore.pyqtSignal]
    channelNameChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setProperty(self, property: str|None) -> None: ...
    def setTarget(self, target: Qt3DCore.QNode|None) -> None: ...
    def setChannelName(self, channelName: str|None) -> None: ...
    def property(self) -> str: ...
    def target(self) -> Qt3DCore.QNode|None: ...
    def channelName(self) -> str: ...


class QClipAnimator('QAbstractClipAnimator'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    clipChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setClip(self, clip: 'QAbstractAnimationClip|None') -> None: ...
    def clip(self) -> 'QAbstractAnimationClip|None': ...


class QClipBlendValue('QAbstractClipBlendNode'):

    @typing.overload
    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...
    @typing.overload
    def __init__(self, clip: 'QAbstractAnimationClip|None', parent: Qt3DCore.QNode|None = ...) -> None: ...

    clipChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setClip(self, clip: 'QAbstractAnimationClip|None') -> None: ...
    def clip(self) -> 'QAbstractAnimationClip|None': ...


class QClock(Qt3DCore.QNode):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    playbackRateChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setPlaybackRate(self, playbackRate: float) -> None: ...
    def playbackRate(self) -> float: ...


class QKeyFrame(PyQt6.sip.simplewrapper):

    class InterpolationType(enum.Enum):
        ConstantInterpolation = ... # type: QKeyFrame.InterpolationType
        LinearInterpolation = ... # type: QKeyFrame.InterpolationType
        BezierInterpolation = ... # type: QKeyFrame.InterpolationType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, coords: QtGui.QVector2D) -> None: ...
    @typing.overload
    def __init__(self, coords: QtGui.QVector2D, lh: QtGui.QVector2D, rh: QtGui.QVector2D) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QKeyFrame') -> None: ...

    def __eq__(self, other: object): ...
    def __ne__(self, other: object): ...
    def interpolationType(self) -> 'QKeyFrame.InterpolationType': ...
    def setInterpolationType(self, interp: 'QKeyFrame.InterpolationType') -> None: ...
    def rightControlPoint(self) -> QtGui.QVector2D: ...
    def setRightControlPoint(self, rh: QtGui.QVector2D) -> None: ...
    def leftControlPoint(self) -> QtGui.QVector2D: ...
    def setLeftControlPoint(self, lh: QtGui.QVector2D) -> None: ...
    def coordinates(self) -> QtGui.QVector2D: ...
    def setCoordinates(self, coords: QtGui.QVector2D) -> None: ...


class QKeyframeAnimation('QAbstractAnimation'):

    class RepeatMode(enum.Enum):
        None_ = ... # type: QKeyframeAnimation.RepeatMode
        Constant = ... # type: QKeyframeAnimation.RepeatMode
        Repeat = ... # type: QKeyframeAnimation.RepeatMode

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    endModeChanged: typing.ClassVar[QtCore.pyqtSignal]
    startModeChanged: typing.ClassVar[QtCore.pyqtSignal]
    targetNameChanged: typing.ClassVar[QtCore.pyqtSignal]
    easingChanged: typing.ClassVar[QtCore.pyqtSignal]
    targetChanged: typing.ClassVar[QtCore.pyqtSignal]
    framePositionsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setEndMode(self, mode: 'QKeyframeAnimation.RepeatMode') -> None: ...
    def setStartMode(self, mode: 'QKeyframeAnimation.RepeatMode') -> None: ...
    def setTargetName(self, name: str|None) -> None: ...
    def setEasing(self, easing: QtCore.QEasingCurve|QtCore.QEasingCurve.Type) -> None: ...
    def setTarget(self, target: Qt3DCore.QTransform|None) -> None: ...
    def setFramePositions(self, positions: collections.abc.Iterable[float]) -> None: ...
    def removeKeyframe(self, keyframe: Qt3DCore.QTransform|None) -> None: ...
    def addKeyframe(self, keyframe: Qt3DCore.QTransform|None) -> None: ...
    def setKeyframes(self, keyframes: collections.abc.Iterable[Qt3DCore.QTransform]) -> None: ...
    def endMode(self) -> 'QKeyframeAnimation.RepeatMode': ...
    def startMode(self) -> 'QKeyframeAnimation.RepeatMode': ...
    def targetName(self) -> str: ...
    def easing(self) -> QtCore.QEasingCurve: ...
    def target(self) -> Qt3DCore.QTransform|None: ...
    def keyframeList(self) -> list[Qt3DCore.QTransform]: ...
    def framePositions(self) -> list[float]: ...


class QLerpClipBlend('QAbstractClipBlendNode'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    endClipChanged: typing.ClassVar[QtCore.pyqtSignal]
    startClipChanged: typing.ClassVar[QtCore.pyqtSignal]
    blendFactorChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setEndClip(self, endClip: 'QAbstractClipBlendNode|None') -> None: ...
    def setStartClip(self, startClip: 'QAbstractClipBlendNode|None') -> None: ...
    def setBlendFactor(self, blendFactor: float) -> None: ...
    def endClip(self) -> 'QAbstractClipBlendNode|None': ...
    def startClip(self) -> 'QAbstractClipBlendNode|None': ...
    def blendFactor(self) -> float: ...


class QMorphingAnimation('QAbstractAnimation'):

    class Method(enum.Enum):
        Normalized = ... # type: QMorphingAnimation.Method
        Relative = ... # type: QMorphingAnimation.Method

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    easingChanged: typing.ClassVar[QtCore.pyqtSignal]
    methodChanged: typing.ClassVar[QtCore.pyqtSignal]
    targetNameChanged: typing.ClassVar[QtCore.pyqtSignal]
    targetChanged: typing.ClassVar[QtCore.pyqtSignal]
    interpolatorChanged: typing.ClassVar[QtCore.pyqtSignal]
    targetPositionsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setEasing(self, easing: QtCore.QEasingCurve|QtCore.QEasingCurve.Type) -> None: ...
    def setMethod(self, method: 'QMorphingAnimation.Method') -> None: ...
    def setTargetName(self, name: str|None) -> None: ...
    def setTarget(self, target: Qt3DRender.QGeometryRenderer|None) -> None: ...
    def setTargetPositions(self, targetPositions: collections.abc.Iterable[float]) -> None: ...
    def morphTargetList(self) -> list['QMorphTarget']: ...
    def getWeights(self, positionIndex: int) -> list[float]: ...
    def setWeights(self, positionIndex: int, weights: collections.abc.Iterable[float]) -> None: ...
    def removeMorphTarget(self, target: 'QMorphTarget|None') -> None: ...
    def addMorphTarget(self, target: 'QMorphTarget|None') -> None: ...
    def setMorphTargets(self, targets: collections.abc.Iterable['QMorphTarget']) -> None: ...
    def easing(self) -> QtCore.QEasingCurve: ...
    def method(self) -> 'QMorphingAnimation.Method': ...
    def targetName(self) -> str: ...
    def target(self) -> Qt3DRender.QGeometryRenderer|None: ...
    def interpolator(self) -> float: ...
    def targetPositions(self) -> list[float]: ...


class QMorphTarget(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    attributeNamesChanged: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def fromGeometry(geometry: Qt3DCore.QGeometry|None, attributes: collections.abc.Iterable[str|None]) -> 'QMorphTarget|None': ...
    def removeAttribute(self, attribute: Qt3DCore.QAttribute|None) -> None: ...
    def addAttribute(self, attribute: Qt3DCore.QAttribute|None) -> None: ...
    def setAttributes(self, attributes: collections.abc.Iterable[Qt3DCore.QAttribute]) -> None: ...
    def attributeNames(self) -> list[str]: ...
    def attributeList(self) -> list[Qt3DCore.QAttribute]: ...


class QSkeletonMapping('QAbstractChannelMapping'):

    def __init__(self, parent: Qt3DCore.QNode|None = ...) -> None: ...

    skeletonChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setSkeleton(self, skeleton: Qt3DCore.QAbstractSkeleton|None) -> None: ...
    def skeleton(self) -> Qt3DCore.QAbstractSkeleton|None: ...


class QVertexBlendAnimation('QAbstractAnimation'):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    targetNameChanged: typing.ClassVar[QtCore.pyqtSignal]
    targetChanged: typing.ClassVar[QtCore.pyqtSignal]
    interpolatorChanged: typing.ClassVar[QtCore.pyqtSignal]
    targetPositionsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setTargetName(self, name: str|None) -> None: ...
    def setTarget(self, target: Qt3DRender.QGeometryRenderer|None) -> None: ...
    def setTargetPositions(self, targetPositions: collections.abc.Iterable[float]) -> None: ...
    def morphTargetList(self) -> list['QMorphTarget']: ...
    def removeMorphTarget(self, target: 'QMorphTarget|None') -> None: ...
    def addMorphTarget(self, target: 'QMorphTarget|None') -> None: ...
    def setMorphTargets(self, targets: collections.abc.Iterable['QMorphTarget']) -> None: ...
    def targetName(self) -> str: ...
    def target(self) -> Qt3DRender.QGeometryRenderer|None: ...
    def interpolator(self) -> float: ...
    def targetPositions(self) -> list[float]: ...
